pHcalc
######

*pHcalc* is a Python library for systematically calculating solution pH,
distribution diagrams, and titration curves.

This package is Python 3.5 compatible with dependencies only on Numpy and
Scipy. Bug fixes, questions, and update requests are encouraged and can be
filed at the `GitHub repo`_. 

The documentation is in progress. There are several examples of typical usage
at the end of the main module file.

.. _Requirements:

Requirements
------------

* Numpy >= 1.10

* Scipy >= 0.17

.. _Optional Packages:

Optional Packages
-----------------

* Matplotlib >= 1.5

   
.. External Hyperlinks

.. _GitHub repo: https://github.com/rnelsonchem/pHcalc
